@@ -1,3 +1,6 @@
 from .hide_code_html_exporter import HideCodeHTMLExporter
 from .hide_code_pdf_exporter import HideCodePDFExporter
-from .hide_code_preprocessor import HideCodePreprocessor
\ No newline at end of file
+from .hide_code_preprocessor import HideCodePreprocessor
+from .hide_code import *
+from .hide_code_config import HideCodeConfig
+from .utils import Utils
\ No newline at end of file
